@@ -50,8 +50,8 @@ class FunctionsAPI(APIClient):
         api_key: Optional[str] = None,
         secrets: Optional[Dict] = None,
         env_vars: Optional[Dict] = None,
-        cpu: Number = 0.25,
-        memory: Number = 1.0,
+        cpu: Optional[Number] = None,
+        memory: Optional[Number] = None,
     ) -> Function:
         """`When creating a function, <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions>`_
         the source code can be specified in one of three ways:\n
@@ -79,8 +79,8 @@ class FunctionsAPI(APIClient):
             api_key (str, optional):                API key that can be used inside the function to access data in CDF.
             secrets (Dict[str, str]):               Additional secrets as key/value pairs. These can e.g. password to simulators or other data sources. Keys must be lowercase characters, numbers or dashes (-) and at most 15 characters. You can create at most 5 secrets, all keys must be unique, and cannot be apikey.
             env_vars (Dict[str, str]):              Environment variables as key/value pairs. Keys can contain only letters, numbers or the underscore character. You can create at most 20 environment variables.
-            cpu (Number):                           Number of CPU cores per function. Defaults to 0.25. Allowed values are in the range [0.1, 0.6].
-            memory (Number):                        Memory per function measured in GB. Defaults to 1. Allowed values are in the range [0.1, 2.5].
+            cpu (Number, optional):                 Number of CPU cores per function. Allowed values are in the range [0.1, 0.6], and None translates to the API default which is 0.25 in GCP. The argument is unavailable in Azure.
+            memory (Number, optional):              Memory per function measured in GB. Allowed values are in the range [0.1, 2.5], and None translates to the API default which is 1 GB in GCP. The argument is unavailable in Azure.
 
         Returns:
             Function: The created function.
@@ -113,8 +113,8 @@ class FunctionsAPI(APIClient):
         elif function_handle:
             _validate_function_handle(function_handle)
             file_id = self._zip_and_upload_handle(function_handle, name)
-        utils._auxiliary.assert_type(cpu, "cpu", [Number], allow_none=False)
-        utils._auxiliary.assert_type(memory, "memory", [Number], allow_none=False)
+        utils._auxiliary.assert_type(cpu, "cpu", [Number], allow_none=True)
+        utils._auxiliary.assert_type(memory, "memory", [Number], allow_none=True)
 
         sleep_time = 1.0  # seconds
         for i in range(MAX_RETRIES):
@@ -134,10 +134,12 @@ class FunctionsAPI(APIClient):
             "owner": owner,
             "fileId": file_id,
             "functionPath": function_path,
-            "cpu": float(cpu),
-            "memory": float(memory),
             "envVars": env_vars,
         }
+        if cpu:
+            function.update({"cpu": cpu})
+        if memory:
+            function.update({"memory": memory})
         if external_id:
             function.update({"externalId": external_id})
         if api_key:
@@ -417,8 +419,7 @@ def _use_client_credentials(cognite_client: CogniteClient, client_credentials: O
         nonce = res.json()["items"][0]["nonce"]
         return nonce
     except CogniteAPIError as e:
-        print("Unable to get nonce using client credentials flow. The session API returned with error:", e.message)
-        return None
+        raise CogniteAPIError("Failed to create session using client credentials flow.") from e
 
 
 def _use_token_exchange(cognite_client: CogniteClient):
@@ -429,7 +430,7 @@ def _use_token_exchange(cognite_client: CogniteClient):
         nonce = res.json()["items"][0]["nonce"]
         return nonce
     except CogniteAPIError as e:
-        print("Unable to get nonce using token exchange flow. The session API returned with error:", e.message)
+        raise CogniteAPIError("Failed to create session using token exchange flow.") from e
 
 
 def _using_client_credential_flow(cognite_client: CogniteClient):
@@ -502,6 +503,16 @@ def _assert_exactly_one_of_function_id_and_function_external_id(function_id, fun
     ), "Exactly one of function_id and function_external_id must be specified"
 
 
+def _assert_at_most_one_of_function_id_and_function_external_id(function_id, function_external_id):
+    utils._auxiliary.assert_type(function_id, "function_id", [Integral], allow_none=True)
+    utils._auxiliary.assert_type(function_external_id, "function_external_id", [str], allow_none=True)
+    has_function_id = function_id is not None
+    has_function_external_id = function_external_id is not None
+    assert not (
+        has_function_id and has_function_external_id
+    ), "Only function_id or function_external_id allowed when listing schedules."
+
+
 class FunctionCallsAPI(APIClient):
     _LIST_CLASS = FunctionCallList
 
@@ -688,6 +699,7 @@ class FunctionSchedulesAPI(APIClient):
     def list(
         self,
         name: str = None,
+        function_id: int = None,
         function_external_id: str = None,
         created_time: Union[Dict[str, int], TimestampRange] = None,
         cron_expression: str = None,
@@ -697,6 +709,7 @@ class FunctionSchedulesAPI(APIClient):
 
         Args:
             name (str): Name of the function schedule.
+            function_id (int): ID of the function the schedules are linked to.
             function_external_id (str): External ID of the function the schedules are linked to.
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             cron_expression (str): Cron expression.
@@ -721,11 +734,14 @@ class FunctionSchedulesAPI(APIClient):
                 >>> schedules = func.list_schedules(limit=None)
 
         """
+        _assert_at_most_one_of_function_id_and_function_external_id(function_id, function_external_id)
+
         if limit in [float("inf"), -1, None]:
             limit = LIST_LIMIT_CEILING
 
         filter = FunctionSchedulesFilter(
             name=name,
+            function_id=function_id,
             function_external_id=function_external_id,
             created_time=created_time,
             cron_expression=cron_expression,
@@ -786,6 +802,7 @@ class FunctionSchedulesAPI(APIClient):
                 {
                     "name": name,
                     "description": description,
+                    "functionId": function_id,
                     "functionExternalId": function_external_id,
                     "cronExpression": cron_expression,
                     "nonce": nonce,
