@@ -8,15 +8,17 @@ from cognite.experimental._api.annotations import AnnotationsAPI
 from cognite.experimental._api.assets import ExperimentalAssetsAPI
 from cognite.experimental._api.document_parsing import DocumentParsingAPI
 from cognite.experimental._api.entity_matching import EntityMatchingAPI
+from cognite.experimental._api.extractionpipelineruns import ExtractionPipelinesRunsAPI
+from cognite.experimental._api.extractionpipelines import ExtractionPipelinesAPI
 from cognite.experimental._api.functions import FunctionsAPI
-from cognite.experimental._api.integrationruns import IntegrationsRunsAPI
-from cognite.experimental._api.integrations import IntegrationsAPI
+from cognite.experimental._api.geospatial import ExperimentalGeospatialAPI
 from cognite.experimental._api.match_rules import MatchRulesAPI
 from cognite.experimental._api.model_hosting import ModelHostingAPI
 from cognite.experimental._api.plot_extraction import PlotDataExtractionAPI
 from cognite.experimental._api.pnid_object_detection import PNIDObjectDetectionAPI
 from cognite.experimental._api.pnid_parsing import DiagramsAPI, PNIDParsingAPI
 from cognite.experimental._api.templatecompletion import ExperimentalTemplatesAPI
+from cognite.experimental._api.transformations import TransformationsAPI
 from cognite.experimental._api.types import TypesAPI
 
 APIClient.RETRYABLE_POST_ENDPOINTS |= {
@@ -98,6 +100,7 @@ class CogniteClient(Client):
 
         self.model_hosting = ModelHostingAPI(self._config, api_version="playground", cognite_client=self)
         self.types = TypesAPI(self._config, api_version="playground", cognite_client=self)
+        self.geospatial = ExperimentalGeospatialAPI(self._config, api_version="v1", cognite_client=self)
 
         self.document_parsing = DocumentParsingAPI(self._config, api_version="playground", cognite_client=self)
         self.entity_matching = EntityMatchingAPI(self._config, api_version="playground", cognite_client=self)
@@ -108,8 +111,12 @@ class CogniteClient(Client):
         self.plot_extraction = PlotDataExtractionAPI(self._config, api_version="playground", cognite_client=self)
 
         self.functions = FunctionsAPI(self.config, api_version="playground", cognite_client=self)
-        self.integrations = IntegrationsAPI(self._config, api_version="playground", cognite_client=self)
-        self.integration_runs = IntegrationsRunsAPI(self._config, api_version="playground", cognite_client=self)
+        self.extraction_pipelines = ExtractionPipelinesAPI(self._config, api_version="playground", cognite_client=self)
+        self.extraction_pipeline_runs = ExtractionPipelinesRunsAPI(
+            self._config, api_version="playground", cognite_client=self
+        )
+
+        self.transformations = TransformationsAPI(self._config, api_version="playground", cognite_client=self)
 
         self.diagrams = DiagramsAPI(self._config, api_version=self._API_VERSION, cognite_client=self)
         # template completion only
